//4つの8桁LEDディスプレイモジュールMAX7219デジタル制御管を繋いだときのスケッチ

#include "LedControl.h"

/////////////////////////////////////////////////////////////////////////
/////////// 7セグメント表示 MAX7219経由 //////////////////
/////////////////////////////////////////////////////////////////////////
// ピン14をデータ入力DINに、13をCLKに、11をLOADに、デバイス数は3個
const int lc_DIN_Pin = 21;    //7セグ、teensyピン位置141312
const int lc_CLK_Pin = 23;
const int lc_LOAD_Pin = 22;
LedControl lc = LedControl(lc_DIN_Pin, lc_CLK_Pin, lc_LOAD_Pin, 4); //カスケード接続の場合、最後の数字が接続したモジュールの数。



//==============================================================================================
/////////// COURSE 7セグメント表示 //////////////////
//==============================================================================================
FlightSimFloat Course_Val;  //7セグ用
float Course_FloatValue;
int Course_IntValue;
//==============================================================================================
/////////// IAS/MACH（エアースピード）7セグメント表示 //////////////////
//==============================================================================================
FlightSimInteger AirSpeed_KnotMach_change;    //ノットとマッハの切り替え用
FlightSimInteger Fms_Vnav;
FlightSimInteger AirSpeed_IntVal;          //小数点以下のデータを取得、７セグ用
FlightSimFloat AirSpeed_FloatVal;
FlightSimFloat VNAV_Pos;
float kts_FloatValue;                         //不動小数点の数値を一時格納
int kts_IntValue;                             //不動小数点を整数に変換
float mach_FloatValue;                        //不動小数点の数値を一時格納
int mach_IntValue;                            //不動小数点を整数に変換
//===============================================================================================
/////////// HEADING 7セグメント表示 //////////////////
//===============================================================================================
FlightSimInteger Heading_Val;
//===============================================================================================
/////////// ALTITUDE 7セグメント表示 //////////////////
//===============================================================================================
FlightSimInteger Altitude_Val;
//===============================================================================================
/////////// VERT SPEED 7セグメント表示 //////////////////
//===============================================================================================
FlightSimInteger VertSpeed_Val;
FlightSimInteger VertSpeed_vs_pos;



void setup() {
  pinMode(13, OUTPUT);  //X-Planeの起動の有効・無効用
  pinMode(lc_DIN_Pin, OUTPUT);
  pinMode(lc_CLK_Pin, OUTPUT);
  pinMode(lc_LOAD_Pin, OUTPUT);

  // 4つのMAX7219デバイスを初期化する
  for (int k = 0; k < 4; k++) { //4はモジュールの数
    lc.shutdown(k, false); // 表示を有効にする
    //lc.setIntensity(k, 5); // 全てのの明るさ（各7セグの明るさの調整をしないと１つだけしか点灯しない場合がある）
    lc.clearDisplay(k);    // 表示レジスタをクリア

    scrollDigits();  //7セグメントテスト用


    //===============================================================================================
    /////////// setup内 1番 COURSE 7セグメント表示 //////////////////
    //===============================================================================================
    Course_Val = XPlaneRef("sim/cockpit2/radios/actuators/hsi_obs_deg_mag_pilot");
    //===============================================================================================
    /////////// setup内 ２番 IAS/MACH（エアースピード）7セグメント表示 //////////////////
    //===============================================================================================
    // loop内で動作設定をしているので、他のように「onChange()」が入っていない。
    AirSpeed_IntVal = XPlaneRef("laminar/B738/autopilot/mcp_speed_dial_kts_mach");  //X-Planeから浮動小数点の数値を取得 sim/cockpit/autopilot/airspeed
    AirSpeed_FloatVal = XPlaneRef("laminar/B738/autopilot/mcp_speed_dial_kts_mach");  //sim/cockpit/autopilot/airspeed
    AirSpeed_KnotMach_change = XPlaneRef("sim/cockpit/autopilot/airspeed_is_mach");
    Fms_Vnav = XPlaneRef("laminar/B738/autopilot/altitude_mode");
    VNAV_Pos = XPlaneRef("laminar/B738/autopilot/vnav_status1");
    //===============================================================================================
    /////////// setup内 ３番 HEADING 7セグメント表示 /////////////////
    //===============================================================================================
    Heading_Val = XPlaneRef("laminar/B738/autopilot/mcp_hdg_dial");
    //===============================================================================================
    /////////// setup内 ４番 ALTTUDE 7セグメント表示 //////////////////
    //===============================================================================================
    Altitude_Val = XPlaneRef("laminar/B738/autopilot/mcp_alt_dial");
    //===============================================================================================
    /////////// setup内 ５番 VERT SPEED 7セグメント表示 //////////////////
    //===============================================================================================
    VertSpeed_Val = XPlaneRef("laminar/B738/autopilot/ap_vvi_pos");
    VertSpeed_vs_pos = XPlaneRef("laminar/B738/autopilot/vvi_dial_show");


  }
}

void loop() {
  FlightSim.update();

  if (FlightSim.isEnabled()) {          //X-Planeが完全に起動し、データの出力が有効になったら。
    digitalWrite(13, HIGH);  //tensy1ピン
  } else {
    lc.setScanLimit(0, 5);
    lc.setIntensity(0, 1);
    lc.setDigit(0, 0, 0, false); //5桁目の値を表示
    lc.setDigit(0, 1, 0, false); //5桁目の値を表示
    lc.setDigit(0, 2, 0, false); //5桁目の値を表示
    lc.setDigit(0, 3, 0, false); //5桁目の値を表示
    lc.setDigit(0, 4, 0, false); //5桁目の値を表示
    lc.setDigit(0, 5, 0, false);
    lc.setDigit(0, 6, 0, false);

    lc.setScanLimit(1, 5);
    lc.setIntensity(1, 1);

    lc.setDigit(1, 0, 0, false); //5桁目の値を表示
    lc.setDigit(1, 1, 0, false); //5桁目の値を表示
    lc.setDigit(1, 2, 0, false); //5桁目の値を表示
    lc.setDigit(1, 3, 0, false); //5桁目の値を表示
    lc.setDigit(1, 4, 0, false); //5桁目の値を表示
    lc.setDigit(1, 5, 0, false);
    lc.setDigit(1, 6, 0, false);

    //lc.setScanLimit(2, 5);
    lc.setIntensity(2, 2);
    lc.setDigit(2, 1, 0, false); //5桁目の値を表示
    lc.setDigit(2, 2, 0, false); //5桁目の値を表示
    lc.setDigit(2, 3, 0, false);

    lc.setDigit(2, 5, 0, false); //5桁目の値を表示
    lc.setDigit(2, 6, 0, false); //5桁目の値を表示
    lc.setDigit(2, 7, 0, false);

    lc.setIntensity(3, 2);
    lc.setDigit(3, 1, 0, false); //5桁目の値を表示
    lc.setDigit(3, 2, 0, false); //5桁目の値を表示
    lc.setDigit(3, 3, 0, false);  

    digitalWrite(13, HIGH);
    delay(1000);
    digitalWrite(13, LOW);
    delay(1000);
  }





  //===============================================================================================
  /////////// loop内 7セグメント COURSE //////////////////
  //===============================================================================================

  float Course_FloatValue = Course_Val;        //ここは下のように小数点以上が3桁だからそのまま（107.974960）、下を見ると理解しやすい。
  Course_FloatValue = round(Course_FloatValue);       //ここで先頭から3番目の数値を四捨五入
  Course_IntValue = (int) Course_FloatValue;

  int Course_Val_keta1 = Course_IntValue % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
  int Course_Val_keta2 = Course_IntValue / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
  int Course_Val_keta3 = Course_IntValue / 100;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
  lc.setIntensity(3, 5);
  lc.setDigit(3, 1, Course_Val_keta1, false); //1桁目の値を表示、falseはドットを表示しない設定。
  lc.setDigit(3, 2, Course_Val_keta2, false); //2桁目の値を表示
  lc.setDigit(3, 3, Course_Val_keta3, false); //3桁目の値を表示



  //===============================================================================================
  /////////// loop内 7セグメント IAS/MACH（エアースピード） //////////////////
  //===============================================================================================
  if (VNAV_Pos == 0) {  //vnav_posが０なら以下を実行
    //起動したときは0（ノット表示）になっている。
    if (AirSpeed_KnotMach_change == 0) {
      float kts_FloatValue = AirSpeed_FloatVal;        //ここは下のように小数点以上が3桁だからそのまま（107.974960）、下を見ると理解しやすい。
      kts_FloatValue = round(kts_FloatValue);       //ここで先頭から3番目の数値を四捨五入
      kts_IntValue = (int) kts_FloatValue;

      //下のコメントアウトは剰余の説明がちょっとおかしいが、これがわかりやすい。
      int AirSpeed_keta1 =  kts_IntValue % 10;       //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
      int AirSpeed_keta2 = kts_IntValue / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
      int AirSpeed_keta3 = kts_IntValue / 100;       //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示

      lc.setDigit(2, 1, AirSpeed_keta1, false);     //1桁目の値を表示
      lc.setDigit(2, 2, AirSpeed_keta2, false);     //2桁目の値を表示
      lc.setDigit(2, 3, AirSpeed_keta3, false);     //3桁目の値を表示
    }

    //マッハ表示（000と小数点以下3桁を表示）
    if (AirSpeed_KnotMach_change == 1) {            //1ということはマッハ表示ということである
      //剰余の場合は浮動小数点が使えないので
      float mach_FloatValue = AirSpeed_FloatVal * 1000;     //所得した小数点を整数の位置にもっていく（0.163277を163.277に）
      mach_FloatValue = round(mach_FloatValue);          //ここで先頭から3番目の数値を四捨五入
      mach_IntValue = (int) mach_FloatValue;             //163.277にした分を完全な整数に変換（163にする）

      int AirSpeed_keta1 = mach_IntValue / 10 % 10 ;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示（何故か1つ少ないので1をプラス）
      int AirSpeed_keta2 = mach_IntValue / 100 ;      //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示

      lc.setDigit(2, 1, AirSpeed_keta1, false);      //1桁目の値を表示
      lc.setDigit(2, 2, AirSpeed_keta2, false);      //2桁目の値を表示
      lc.setDigit(2, 3, 0, true); //3桁目の値を表示
    }
  }
  if (VNAV_Pos == 1) { 
      lc.setChar(2, 1, ' ', false);
      lc.setChar(2, 2, ' ', false);
      lc.setChar(2, 3, ' ', false);
  }

  //===============================================================================================
  /////////// loop内 7セグメント HEADING //////////////////
  //===============================================================================================
  //lc.setScanLimit(2, 7);//2の中で１つだけ設定すればいいのでいらない
  int Heading_Val_keta1 = Heading_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
  int Heading_Val_keta2 = Heading_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
  int Heading_Val_keta3 = Heading_Val / 100;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
  lc.setIntensity(2, 5);
  lc.setDigit(2, 5, Heading_Val_keta1, false); //1桁目の値を表示、falseはドットを表示しない設定。
  lc.setDigit(2, 6, Heading_Val_keta2, false); //2桁目の値を表示
  lc.setDigit(2, 7, Heading_Val_keta3, false); //3桁目の値を表示



  //===============================================================================================
  /////////// loop内 7セグメント ALTITUDE //////////////////
  //===============================================================================================
  //数値の回転制限（数字が止まるところ）はエンコーダ側で行う。但し、こちらで制限することもできるがX-Planeと違った数値になるので注意が必要。
  //表示する桁数を変更する設定
  //プラスの3桁表示用
  if (Altitude_Val >= 0 && Altitude_Val <= 999) {    //もし、999より小さいなら以下を実行
    lc.setScanLimit(1, 2);  // 3桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）本当は2だが、0を使っていないので3になっている
    lc.setIntensity(1, 1); // ここだけ明るすぎるので特別に落とした。
    //プラスの値の処理
    //int Altitude_Val_keta1 = Altitude_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    //int Altitude_Val_keta2 = Altitude_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int Altitude_Val_keta3 = Altitude_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    //int Altitude_Val_keta4 = Altitude_Val / 1000 % 10;
    lc.setDigit(1, 0, 0, false); //1桁目の値を表示
    lc.setDigit(1, 1, 0, false); //2桁目の値を表示
    lc.setDigit(1, 2, Altitude_Val_keta3, false); //3桁目の値を表示
    //lc4.setDigit(0, 3, Altitude_Val_keta4, false); //4桁目の値を表示
  }
  //プラスの4桁表示用
  else if (Altitude_Val >= 1000 && Altitude_Val <= 9999) {    //もし、999より小さいなら以下を実行
    lc.setScanLimit(1, 3);  // 1000以上、9999以下なら、4桁表示にする
    lc.setIntensity(1, 2);
    //lc4.setIntensity(0, 5); // 15 = brightest
    //プラスの値の処理
    //int Altitude_Val_keta1 = Altitude_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    //int Altitude_Val_keta2 = Altitude_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int Altitude_Val_keta3 = Altitude_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    int Altitude_Val_keta4 = Altitude_Val / 1000 % 10;
    lc.setDigit(1, 0, 0, false); //1桁目の値を表示（現在0の数字を表示するようにしている）
    lc.setDigit(1, 1, 0, false); //2桁目の値を表示（現在0の数字を表示するようにしている）
    lc.setDigit(1, 2, Altitude_Val_keta3, false); //3桁目の値を表示
    lc.setDigit(1, 3, Altitude_Val_keta4, false); //4桁目の値を表示
  }
  //プラスの5桁表示用
  else if (Altitude_Val >= 10000 && Altitude_Val <= 100000) {
    lc.setScanLimit(1, 4);  //10000以上、100000以下なら、5桁表示にする
    lc.setIntensity(1, 4);
    //int Altitude_Val_keta1 = Altitude_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    //int Altitude_Val_keta2 = Altitude_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int Altitude_Val_keta3 = Altitude_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    int Altitude_Val_keta4 = Altitude_Val / 1000 % 10;
    int Altitude_Val_keta5 = Altitude_Val / 10000 % 10;
    lc.setDigit(1, 0, 0, false); //1桁目の値を表示（現在0の数字を表示するようにしている）
    lc.setDigit(1, 1, 0, false); //2桁目の値を表示（現在0の数字を表示するようにしている）
    lc.setDigit(1, 2, Altitude_Val_keta3, false); //3桁目の値を表示
    lc.setDigit(1, 3, Altitude_Val_keta4, false); //4桁目の値を表示
    lc.setDigit(1, 4, Altitude_Val_keta5, false); //5桁目の値を表示
  }
  else {
    lc.setScanLimit(1, 4);  //そうでないなら、5桁表示にする
  }

  //===============================================================================================
  /////////// loop内 7セグメント VERT SPEED //////////////////
  //===============================================================================================
  //表示する桁数を変更する設定
  if (VertSpeed_vs_pos == 0) {        //もし、0と同じなら以下を実行
    lc.setScanLimit(0, 0);      // 1桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    lc.setChar(0, 0, ' ', false); //0になったら数値を表示しないように空白を入れている
  }
  //プラスの値の処理
  else if (VertSpeed_Val == 50 ) {     //もし、999より小さいなら以下を実行
    lc.setIntensity(0, 1);
    lc.setScanLimit(0, 2);                          // 3桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    int VertSpeed_Val_keta1 = VertSpeed_Val % 10;            //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta2 = VertSpeed_Val / 10 % 10 ;      //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    //int VertSpeed_Val_keta3 = VertSpeed_Val / 100 % 10;      //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    lc.setDigit(0, 0, VertSpeed_Val_keta1, false);  //1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta2, false);  //2桁目の値を表示
    lc.setChar(0, 2, ' ', false);       //3桁目に空白を表示
  }
  //プラスの値の処理
  else if (VertSpeed_Val >= 100 && VertSpeed_Val <= 999) {     //もし、999より小さいなら以下を実行
    //lc.setIntensity(0, 1);
    lc.setScanLimit(0, 2);
    int VertSpeed_Val_keta1 = VertSpeed_Val % 10;            //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta2 = VertSpeed_Val / 10 % 10 ;      //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int VertSpeed_Val_keta3 = VertSpeed_Val / 100 % 10;      //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示                         // 3桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    lc.setDigit(0, 0, VertSpeed_Val_keta1, false);  //1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta2, false);  //2桁目の値を表示
    lc.setDigit(0, 2, VertSpeed_Val_keta3, false);  //3桁目の値を表示
  }
  else if (VertSpeed_Val >= 1000 && VertSpeed_Val <= 5000) {    //X-Planeで扱えるプラス側は5000まで（エンコーダ側でこれ以上がらないようにストップさせる）
    lc.setIntensity(0, 2);
    lc.setScanLimit(0, 3);
    //プラスの値の処理
    int VertSpeed_Val_keta1 = VertSpeed_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta2 = VertSpeed_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int VertSpeed_Val_keta3 = VertSpeed_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    int VertSpeed_Val_keta4 = VertSpeed_Val / 1000 % 10;
    lc.setDigit(0, 0, VertSpeed_Val_keta1, false); //1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta2, false); //2桁目の値を表示
    lc.setDigit(0, 2, VertSpeed_Val_keta3, false); //3桁目の値を表示
    lc.setDigit(0, 3, VertSpeed_Val_keta4, false); //4桁目の値を表示
  }

  //マイナスの数値表示
  else if (VertSpeed_Val >= -50) {   //もし、-999より下で-100より上なら以下を実行
    lc.setIntensity(0, 1);
    int VertSpeed_Val_keta_Minus1 = - VertSpeed_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta_Minus2 = - VertSpeed_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    //マイナスの値の処理
    lc.setScanLimit(0, 3);  // 4桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    lc.setDigit(0, 0, VertSpeed_Val_keta_Minus1, false); //-の1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta_Minus2, false); //-の2桁目の値を表示
    lc.setChar(0, 3, ' ', false);       //5桁目に-空白を表示
    lc.setChar(0, 3, '-', false);       //5桁目に-を表示
  }

  //マイナスの数値表示
  else if (VertSpeed_Val >= -999 && VertSpeed_Val <= -100) {   //もし、-999より下で-100より上なら以下を実行
    lc.setIntensity(0, 1);
    int VertSpeed_Val_keta_Minus1 = - VertSpeed_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta_Minus2 = - VertSpeed_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int VertSpeed_Val_keta_Minus3 = - VertSpeed_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    //マイナスの値の処理
    lc.setScanLimit(0, 3);  // 4桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    lc.setDigit(0, 0, VertSpeed_Val_keta_Minus1, false); //-の1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta_Minus2, false); //-の2桁目の値を表示
    lc.setDigit(0, 2, VertSpeed_Val_keta_Minus3, false); //-の3桁目の値を表示
    lc.setChar(0, 3, '-', false);       //5桁目に-を表示

  }
  else if (VertSpeed_Val >= -5000 && VertSpeed_Val <= -1000) {    //X-Planeで扱えるプラス側は-5000まで（エンコーダ側でこれ以上がらないようにストップさせる）
    int VertSpeed_Val_keta_Minus1 = - VertSpeed_Val % 10;  //例えば123の数字の場合、123÷10＝12.3で小数点以下の3が1桁の数字として表示
    int VertSpeed_Val_keta_Minus2 = - VertSpeed_Val / 10 % 10 ;  //例えば123の数字の場合、、÷10＝12.3、さらに10で割って、1.23で小数点以下の2が表示
    int VertSpeed_Val_keta_Minus3 = - VertSpeed_Val / 100 % 10;   //例えば123の数字の場合、123÷100＝1.23で1の整数が3桁目の数字として表示
    int VertSpeed_Val_keta_Minus4 = - VertSpeed_Val / 1000 % 10;
    //マイナスの値の処理
    lc.setScanLimit(0, 4);  // 4桁表示にする。（最初は行数、2番めが桁数、0が1桁、1が2桁…）
    lc.setDigit(0, 0, VertSpeed_Val_keta_Minus1, false); //-の1桁目の値を表示
    lc.setDigit(0, 1, VertSpeed_Val_keta_Minus2, false); //-の2桁目の値を表示
    lc.setDigit(0, 2, VertSpeed_Val_keta_Minus3, false); //-の3桁目の値を表示
    lc.setDigit(0, 3, VertSpeed_Val_keta_Minus4, false); //-の4桁目の値を表示
    lc.setChar(0, 4, '-', false);       //5桁目に-を表示
  }
  else {
    lc.setScanLimit(0, 2);  //そうでないなら、3桁表示にする
  }

}
//loop End


//7セグメント起動テスト用
void scrollDigits() {
  //7から0までの数字
  for (int a = 0; a < 8; a++) //0~7を順番に読み込む
  {
    lc.setDigit(0, a, a, false); //aの数の桁を読み込み、aの数を表示
    lc.setDigit(1, a, a, false);
    lc.setDigit(2, a, a, false);
    lc.setDigit(3, a, a, false);
    delay(100);  //順番にこの時間間隔で7〜0を表示
  }
  //delay(1000);

  //すべてのセグメントに8番を表示
  for (int a = 0; a < 8; a++)
  {
    lc.setDigit(0, a, 8, false);
    lc.setDigit(1, a, 8, false);
    lc.setDigit(2, a, 8, false);
    lc.setDigit(3, a, 8, false);
    delay(100);  //順番にこの時間間隔で8を表示
  }
  //delay(1000);

  //明るさを段々暗くする
  for (int a = 8; a >= 0; a--)
  {
    lc.setIntensity(0, a);
    lc.setIntensity(1, a);
    lc.setIntensity(2, a);
    lc.setIntensity(3, a);
    delay(200);  //順番にこの時間間隔で7〜0を表
  }
}
